summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberprotocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabberprotocol.h')
-rw-r--r--kopete/protocols/jabber/jabberprotocol.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/jabberprotocol.h b/kopete/protocols/jabber/jabberprotocol.h
index 35c8cdbc..696d572b 100644
--- a/kopete/protocols/jabber/jabberprotocol.h
+++ b/kopete/protocols/jabber/jabberprotocol.h
@@ -39,30 +39,31 @@
namespace XMPP
{
class Resource;
- class Status;
+ class tqStatus;
}
class JabberContact;
-class dlgJabberStatus;
+class dlgJabbertqStatus;
class dlgJabberSendRaw;
class JabberCapabilitiesManager;
class JabberProtocol:public Kopete::Protocol
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Object constructor and destructor
*/
- JabberProtocol (TQObject * parent, const char *name, const TQStringList &);
+ JabberProtocol (TQObject * tqparent, const char *name, const TQStringList &);
~JabberProtocol ();
/**
* Creates the "add contact" dialog specific to this protocol
*/
- virtual AddContactPage *createAddContactWidget (TQWidget * parent, Kopete::Account * i);
- virtual KopeteEditAccountWidget *createEditAccountWidget (Kopete::Account * account, TQWidget * parent);
+ virtual AddContactPage *createAddContactWidget (TQWidget * tqparent, Kopete::Account * i);
+ virtual KopeteEditAccountWidget *createEditAccountWidget (Kopete::Account * account, TQWidget * tqparent);
virtual Kopete::Account *createNewAccount (const TQString & accountId);
/**
@@ -94,8 +95,8 @@ public:
const Kopete::ContactPropertyTmpl propWorkPhone;
const Kopete::ContactPropertyTmpl propWorkMobilePhone;
const Kopete::ContactPropertyTmpl propNickName;
- const Kopete::ContactPropertyTmpl propSubscriptionStatus;
- const Kopete::ContactPropertyTmpl propAuthorizationStatus;
+ const Kopete::ContactPropertyTmpl propSubscriptiontqStatus;
+ const Kopete::ContactPropertyTmpl propAuthorizationtqStatus;
const Kopete::ContactPropertyTmpl propAvailableResources;
const Kopete::ContactPropertyTmpl propVCardCacheTimeStamp;
const Kopete::ContactPropertyTmpl propPhoto;
@@ -140,9 +141,9 @@ public:
Kopete::OnlineStatus resourceToKOS ( const XMPP::Resource &resource );
/**
* Convert an online status to a XMPP::Status
*/
- XMPP::Status kosToStatus( const Kopete::OnlineStatus & status, const TQString& message=TQString() );
+ XMPP::tqStatus kosTotqStatus( const Kopete::OnlineStatus & status, const TQString& message=TQString() );
/**
* Return the Entity Capabilities(JEP-0115) manager instance.
@@ -140,9 +141,9 @@ public:
Kopete::OnlineStatus resourceToKOS ( const XMPP::Resource &resource );
/**
- * Convert an online status to a XMPP::Status
+ * Convert an online status to a XMPP::tqStatus
*/